%global _hardened_build 1
%global use_systemd 1

Name:		globus-gatekeeper
%global _name %(tr - _ <<< %{name})
Version:	11.4
Release:    2%{?dist}
Summary:	Grid Community Toolkit - Globus Gatekeeper

License:	Apache-2.0
URL:		https://github.com/gridcf/gct/
Source0:		https://repo.gridcf.org/gct6/sources/%{_name}-%{version}.tar.gz
Source1:	%{name}.service
Source2:	%{name}
Source3:	%{name}.README
Source8:	README

BuildRequires:	make
BuildRequires:	gcc
BuildRequires:	globus-common-devel >= 15
BuildRequires:	globus-gss-assist-devel >= 8
BuildRequires:	globus-gssapi-gsi-devel >= 9
BuildRequires:	openssl-devel
%if %{use_systemd}
BuildRequires:	systemd
%endif

Requires:	logrotate

%if %{use_systemd}
%{?systemd_requires}
%else
Requires(post):		chkconfig
Requires(preun):	chkconfig
Requires(preun):	initscripts
Requires(postun):	initscripts
%endif

%description
The Grid Community Toolkit (GCT) is an open source software toolkit used for
building grid systems and applications. It is a fork of the Globus Toolkit
originally created by the Globus Alliance. It is supported by the Grid
Community Forum (GridCF) that provides community-based support for core
software packages in grid computing.

The %{name} package contains:
Globus Gatekeeper

%prep
%setup -q -n %{_name}-%{version}

%build
export LDFLAGS="-Wl,--as-needed -Wl,-z,defs %{?__global_ldflags}"

%configure --disable-static \
	   --includedir=%{_includedir}/globus \
	   --libexecdir=%{_datadir}/globus \
	   --docdir=%{_pkgdocdir} \
	   --with-initscript-config-path=%{_sysconfdir}/sysconfig/%{name} \
	   --with-lockfile-path=/run/lock/subsys/%{name}

sed 's!CC \(.*-shared\) !CC \\\${wl}--as-needed \1 !' -i libtool

%make_build

%install
%make_install

rm -rf %{buildroot}%{_sysconfdir}/init.d

%if %{use_systemd}
mkdir -p %{buildroot}%{_unitdir}
install -m 644 -p %{SOURCE1} %{buildroot}%{_unitdir}
%else
mkdir -p %{buildroot}%{_initddir}
install -p %{SOURCE2} %{buildroot}%{_initddir}
%endif

install -m 644 -p %{SOURCE3} %{buildroot}%{_pkgdocdir}/README.OpenCloudOS

install -m 644 -p %{SOURCE8} %{buildroot}%{_pkgdocdir}/README

rm %{buildroot}%{_pkgdocdir}/GLOBUS_LICENSE

mkdir -p %{buildroot}%{_sysconfdir}/grid-services
mkdir -p %{buildroot}%{_sysconfdir}/grid-services/available

%if %{use_systemd}

%pre
/sbin/chkconfig --del %{name} > /dev/null 2>&1 || :

%post
%systemd_post %{name}.service

%preun
%systemd_preun %{name}.service

%postun
%systemd_postun_with_restart %{name}.service

%else

%post
if [ $1 -eq 1 ]; then
    /sbin/chkconfig --add %{name}
fi

%preun
if [ $1 -eq 0 ]; then
    /sbin/service %{name} stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del %{name}
fi

%postun
if [ $1 -ge 1 ]; then
    /sbin/service %{name} condrestart > /dev/null 2>&1 || :
fi

%endif

%files
%{_sbindir}/globus-gatekeeper
%{_sbindir}/globus-k5
%if %{use_systemd}
%{_unitdir}/%{name}.service
%else
%{_initddir}/%{name}
%endif
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%dir %{_sysconfdir}/grid-services
%dir %{_sysconfdir}/grid-services/available
%doc %{_mandir}/man8/globus-gatekeeper.8*
%doc %{_mandir}/man8/globus-k5.8*
%dir %{_pkgdocdir}
%doc %{_pkgdocdir}/README
%doc %{_pkgdocdir}/README.OpenCloudOS
%license GLOBUS_LICENSE

%changelog
* Mon Apr 22 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 11.4-2
- rebase to add ocs macros

* Mon Apr 15 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 11.4-1
- initial build
